"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadTheme = void 0;
const fs = require("fs");
const path = require("path");
const plist_1 = require("./plist");
const JSON5 = require("json5");
function loadJSONTheme(themePath) {
    const fileContents = fs.readFileSync(themePath, 'utf-8');
    return JSON5.parse(fileContents);
}
function loadPListTheme(themePath) {
    const fileContents = fs.readFileSync(themePath, 'utf-8');
    return plist_1.parse(fileContents);
}
function toShikiTheme(rawTheme) {
    const shikiTheme = {
        ...rawTheme,
        bg: getThemeBg(rawTheme)
    };
    if (rawTheme.include) {
        shikiTheme.include = rawTheme.include;
    }
    if (rawTheme.tokenColors) {
        shikiTheme.settings = rawTheme.tokenColors;
    }
    return shikiTheme;
}
/**
 * @param themePath Absolute path to theme.json / theme.tmTheme
 */
function loadTheme(themePath) {
    let theme;
    if (/\.json$/.test(themePath)) {
        theme = loadJSONTheme(themePath);
    }
    else {
        theme = loadPListTheme(themePath);
    }
    const shikiTheme = toShikiTheme(theme);
    if (shikiTheme.include) {
        const includedThemePath = path.resolve(themePath, '..', shikiTheme.include);
        const includedTheme = loadTheme(includedThemePath);
        if (includedTheme.settings) {
            shikiTheme.settings = shikiTheme.settings.concat(includedTheme.settings);
        }
        if (includedTheme.bg && !shikiTheme.bg) {
            shikiTheme.bg = includedTheme.bg;
        }
    }
    return shikiTheme;
}
exports.loadTheme = loadTheme;
function getThemeBg(theme) {
    if (theme.colors && theme.colors['editor.background']) {
        return theme.colors['editor.background'];
    }
    let settings = theme.settings ? theme.settings : theme.tokenColors;
    const globalSetting = settings.find(s => {
        return !s.name && !s.scope;
    });
    return globalSetting ? globalSetting.settings.background : null;
}
